@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
 use strict;
 use warnings;
@@ -106,7 +106,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0104
+version 0.0105
 
 =head1 SYNOPSIS
 
@@ -124,9 +124,10 @@ version 0.0104
 C<MIDI::Chord::Guitar> provides MIDI pitches for common chord voicings
 of an C<E A D G B E> tuned guitar.
 
-=for html <p>Here is a handy diagram of MIDI pitch octaves laid out on a guitar neck:</p>
-<br>
+=for html <p>Here is a handy diagram of ISO MIDI pitches laid out on a guitar neck:</p>
 <img src="https://raw.githubusercontent.com/ology/MIDI-Chord-Guitar/main/guitar-position-midi-octaves.png">
+<p>And here is a diagram of MIDI pitch numbers laid out on a guitar neck:</p>
+<img src="https://raw.githubusercontent.com/ology/MIDI-Chord-Guitar/main/guitar-position-midi-numbers.png">
 
 =head1 ATTRIBUTES
 
@@ -144,12 +145,12 @@ They are as follows:
   dim
   dim7
   m (minor)
-  m11
   m6
   m7
   m7b5
   m7b5#9
   m9
+  m11
   maj7
   maj7#11
   maj9
@@ -186,6 +187,9 @@ Find the chord given the B<target>, B<chord_name> and B<variation>.
 The B<target> must be in the format of an C<ISO> note (e.g. on the
 guitar, a C note is represented by C<C3>, C<C4>, C<C5>, etc).
 
+There is no logic to the order of the voicing variations of a chord.
+Please use the above diagrams to figure out the neck positions.
+
 =head2 voicings
 
   $mcg->voicings($chord_name);
